OMEGAlpes Examples
===================

Detailed documentation
----------------------
Please find a full description to detail the steps to create a model in the documentation :
https://omegalpes-examples.readthedocs.io/en/latest/


Basic example. PV self-consumption
----------------------------------
In this PV self-consuption example, a single-house with roof-integrated photovoltaic 
panels (PV) is studied. Specifically, the study case is about demand-side management 
in order to maximize the self-consumption, by shifting two household appliances consumption 
(clothes washing machine and clothes dryer) and using a water tank for the
domestic hot water consumption. This example is available online at:
https://cocalc.com/share/f34239ec-d317-420c-9e32-050b10689810/example_BS.ipynb?viewer=share

.. figure::  images/example_PV_self_consumption.png
   :align:   center
   :scale:   50%

   *Figure 1: Principle diagram of the PV self-consumption example*
   
   
